@@ -1,10 +1,8 @@
 import requests
 from lxml import etree
 import xlwt
-import re
 #SinglePageXpath
-from SimpleSpider import SimpleSpider
-
+import re
 def SinglePageGetByXpath(Url,Xpath,Header=False,Cookie=False):
     if(Header==False):
         if(Cookie==False):
@@ -92,6 +90,9 @@ def SinglePageGetByRegEx(Url,RegEx,Header=False,Cookie=False):
     if(Header == False):
         if(Cookie==False):
             result = requests.get(Url)
+        else:
+            result = requests.get(Url, cookies=Cookie)
+
     else:
         if(Cookie==False):
             result = requests.get(Url,headers=Header)
@@ -262,12 +263,9 @@ if __name__ == '__main__':
             if (args.output != None):
                 ExportFileToExcel(result, args.output)
         else:
-            result = MulityPageGetByXpath(Url=args.url, IndexList=indexlist, RegEx=args.re)
+            result = MulityPageGetByXpath(Url=args.url, IndexList=indexlist,  Xpath=args.xpath)
             if (args.print == "True"):
                 print(result)
             if (args.output != None):
                 ExportFileToExcel(result, args.output)
 
-
-
-
