@@ -12,6 +12,8 @@ def main():
     parser.add_argument('--print', type=str, default="True")
     parser.add_argument('--output',type=str, default=None )
 
+
+
     args = parser.parse_args()
 
     if(args.single=="True"):
@@ -19,7 +21,7 @@ def main():
                 result=SimpleSpider.SinglePageGetByRegEx(Url=args.url,RegEx=args.re)
                 if(args.print=="True"):
                     for i in result:
-                        print(i)
+                            print(i)
                 if (args.output != None):
                     SimpleSpider.ExportFileToExcel(result, args.output)
 
@@ -42,7 +44,7 @@ def main():
             if (args.output != None):
                 SimpleSpider.ExportFileToExcel(result, args.output)
         else:
-            result = SimpleSpider.MulityPageGetByXpath(Url=args.url, IndexList=indexlist, RegEx=args.re)
+            result = SimpleSpider.MulityPageGetByXpath(Url=args.url, IndexList=indexlist, Xpath=args.xpath)
             if (args.print == "True"):
                 for i in result:
                     print(i)
